# Mezzanine portfolio application

Minimalistic Bootstrap theme for Django/Mezzanine.

## Installation

`pip install mezzanine-portfolio`

## Usage

It is recommended to place the app at the end of INSTALLED_APPS list.

    INSTALLED_APPS = (
        ...
        'portfolio',
    )

##External Links

* Django: www.djangoproject.com
* Mezzanine: www.mezzanine.jupo.org
* PyPI: www.pypi.python.org/pypi/mezzanine-theme-ascetic
* Author: www.izhukov.herokuapp.com